summaryrefslogtreecommitdiff
path: root/sw/source/core/doc/doclay.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/doc/doclay.cxx')
-rw-r--r--sw/source/core/doc/doclay.cxx78
1 files changed, 39 insertions, 39 deletions
diff --git a/sw/source/core/doc/doclay.cxx b/sw/source/core/doc/doclay.cxx
index 9bee9bf6d4c1..e05b5b6339da 100644
--- a/sw/source/core/doc/doclay.cxx
+++ b/sw/source/core/doc/doclay.cxx
@@ -104,7 +104,7 @@
using namespace ::com::sun::star;
-#define DEF_FLY_WIDTH 2268 // Default width for FlyFrms (2268 == 4cm)
+#define DEF_FLY_WIDTH 2268 // Default width for FlyFrames (2268 == 4cm)
static bool lcl_IsItemSet(const SwContentNode & rNode, sal_uInt16 which)
{
@@ -261,7 +261,7 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
if( SfxItemState::SET != pFormat->GetAttrSet().GetItemState( RES_FRM_SIZE ))
{
- SwFormatFrmSize aFormatSize( ATT_VAR_SIZE, 0, DEF_FLY_WIDTH );
+ SwFormatFrameSize aFormatSize( ATT_VAR_SIZE, 0, DEF_FLY_WIDTH );
const SwNoTextNode* pNoTextNode = rNode.GetNoTextNode();
if( pNoTextNode )
{
@@ -281,7 +281,7 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
// Set up frames
if( getIDocumentLayoutAccess().GetCurrentViewShell() )
- pFormat->MakeFrms(); // ???
+ pFormat->MakeFrames(); // ???
if (GetIDocumentUndoRedo().DoesUndo())
{
@@ -506,10 +506,10 @@ static bool lcl_TstFlyRange( const SwPaM* pPam, const SwPosition* pFlyPos,
return bOk;
}
-SwPosFlyFrms SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
+SwPosFlyFrames SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
bool bAsCharAlso ) const
{
- SwPosFlyFrms aRetval;
+ SwPosFlyFrames aRetval;
// collect all anchored somehow to paragraphs
for( auto pFly : *GetSpzFrameFormats() )
@@ -529,7 +529,7 @@ SwPosFlyFrms SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
if( pCmpRange &&
!lcl_TstFlyRange( pCmpRange, pAPos, rAnchor.GetAnchorId() ))
continue; // not a valid FlyFrame
- aRetval.insert(SwPosFlyFrmPtr(new SwPosFlyFrm(pAPos->nNode, pFly, aRetval.size())));
+ aRetval.insert(SwPosFlyFramePtr(new SwPosFlyFrame(pAPos->nNode, pFly, aRetval.size())));
}
}
}
@@ -541,7 +541,7 @@ SwPosFlyFrms SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
return aRetval;
}
- const SwPageFrm *pPage = static_cast<const SwPageFrm*>(getIDocumentLayoutAccess().GetCurrentLayout()->GetLower());
+ const SwPageFrame *pPage = static_cast<const SwPageFrame*>(getIDocumentLayoutAccess().GetCurrentLayout()->GetLower());
while( pPage )
{
if( pPage->GetSortedObjs() )
@@ -551,7 +551,7 @@ SwPosFlyFrms SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
{
SwAnchoredObject* pAnchoredObj = rObjs[i];
SwFrameFormat *pFly;
- if ( dynamic_cast<const SwFlyFrm*>( pAnchoredObj) != nullptr )
+ if ( dynamic_cast<const SwFlyFrame*>( pAnchoredObj) != nullptr )
pFly = &(pAnchoredObj->GetFrameFormat());
else if ( bDrawAlso )
pFly = &(pAnchoredObj->GetFrameFormat());
@@ -563,28 +563,28 @@ SwPosFlyFrms SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
(FLY_AT_FLY != rAnchor.GetAnchorId()) &&
(FLY_AT_CHAR != rAnchor.GetAnchorId()))
{
- const SwContentFrm * pContentFrm = pPage->FindFirstBodyContent();
- if ( !pContentFrm )
+ const SwContentFrame * pContentFrame = pPage->FindFirstBodyContent();
+ if ( !pContentFrame )
{
// Oops! An empty page.
// In order not to lose the whole frame (RTF) we
// look for the last Content before the page.
- const SwPageFrm *pPrv = static_cast<const SwPageFrm*>(pPage->GetPrev());
- while ( !pContentFrm && pPrv )
+ const SwPageFrame *pPrv = static_cast<const SwPageFrame*>(pPage->GetPrev());
+ while ( !pContentFrame && pPrv )
{
- pContentFrm = pPrv->FindFirstBodyContent();
- pPrv = static_cast<const SwPageFrm*>(pPrv->GetPrev());
+ pContentFrame = pPrv->FindFirstBodyContent();
+ pPrv = static_cast<const SwPageFrame*>(pPrv->GetPrev());
}
}
- if ( pContentFrm )
+ if ( pContentFrame )
{
- SwNodeIndex aIdx( *pContentFrm->GetNode() );
- aRetval.insert(SwPosFlyFrmPtr(new SwPosFlyFrm(aIdx, pFly, aRetval.size())));
+ SwNodeIndex aIdx( *pContentFrame->GetNode() );
+ aRetval.insert(SwPosFlyFramePtr(new SwPosFlyFrame(aIdx, pFly, aRetval.size())));
}
}
}
}
- pPage = static_cast<const SwPageFrm*>(pPage->GetNext());
+ pPage = static_cast<const SwPageFrame*>(pPage->GetNext());
}
return aRetval;
@@ -717,8 +717,8 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
SwFrameFormat *pOldFormat = rDoc.GetNodes()[nNdIdx]->GetFlyFormat();
OSL_ENSURE( pOldFormat, "Couldn't find the Fly's Format." );
// #i115719#
// <title> and <description> attributes are lost when calling <DelFrms()>.
// Thus, keep them and restore them after the calling <MakeFrms()>
const bool bIsSwFlyFrameFormatInstance( dynamic_cast<SwFlyFrameFormat*>(pOldFormat) != nullptr );
const OUString sTitle( bIsSwFlyFrameFormatInstance
? static_cast<SwFlyFrameFormat*>(pOldFormat)->GetObjTitle()
@@ -726,7 +726,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
const OUString sDescription( bIsSwFlyFrameFormatInstance
? static_cast<SwFlyFrameFormat*>(pOldFormat)->GetObjDescription()
: OUString() );
- pOldFormat->DelFrms();
+ pOldFormat->DelFrames();
pNewFormat = rDoc.MakeFlyFrameFormat( rDoc.GetUniqueFrameName(),
rDoc.getIDocumentStylePoolAccess().GetFrameFormatFromPool(RES_POOLFRM_FRAME) );
@@ -777,9 +777,9 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
pNewSet->Put( pOldFormat->GetAnchor() );
// The new one should be changeable in its height.
- SwFormatFrmSize aFrmSize( pOldFormat->GetFrmSize() );
- aFrmSize.SetHeightSizeType( ATT_MIN_SIZE );
- pNewSet->Put( aFrmSize );
+ SwFormatFrameSize aFrameSize( pOldFormat->GetFrameSize() );
+ aFrameSize.SetHeightSizeType( ATT_MIN_SIZE );
+ pNewSet->Put( aFrameSize );
SwStartNode* pSttNd = rDoc.GetNodes().MakeTextSection(
SwNodeIndex( rDoc.GetNodes().GetEndOfAutotext() ),
@@ -824,10 +824,10 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
pNewSet->Put( SwFormatVertOrient( 0, eVert ) );
pNewSet->Put( SwFormatHoriOrient( 0, text::HoriOrientation::CENTER ) );
- aFrmSize = pOldFormat->GetFrmSize();
- aFrmSize.SetWidthPercent(0);
- aFrmSize.SetHeightPercent(SwFormatFrmSize::SYNCED);
- pNewSet->Put( aFrmSize );
+ aFrameSize = pOldFormat->GetFrameSize();
+ aFrameSize.SetWidthPercent(0);
+ aFrameSize.SetHeightPercent(SwFormatFrameSize::SYNCED);
+ pNewSet->Put( aFrameSize );
// Hard-set the attributes, because they could come from the Template
// and then size calculations could not be correct anymore.
@@ -856,7 +856,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
// Have only the FlyFrames created.
// We leave this to established methods (especially for InCntFlys).
- pNewFormat->MakeFrms();
+ pNewFormat->MakeFrames();
// #i115719#
if ( bIsSwFlyFrameFormatInstance )
{
@@ -1032,7 +1032,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
// Removing the frames of the drawing object changes its layer.
const SdrLayerID nLayerId = rSdrObj.GetLayer();
- pOldFormat->DelFrms();
+ pOldFormat->DelFrames();
// InContents need to be treated in a special way:
// The TextAttribute needs to be destroyed.
@@ -1072,8 +1072,8 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
// The new one should be variable in its height!
Size aSz( rSdrObj.GetCurrentBoundRect().GetSize() );
- SwFormatFrmSize aFrmSize( ATT_MIN_SIZE, aSz.Width(), aSz.Height() );
- pNewSet->Put( aFrmSize );
+ SwFormatFrameSize aFrameSize( ATT_MIN_SIZE, aSz.Width(), aSz.Height() );
+ pNewSet->Put( aFrameSize );
// Apply the margin to the new Frame.
// Don't set a border, use the one from the Template.
@@ -1160,7 +1160,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
// Have only the FlyFrames created.
// We leave this to established methods (especially for InCntFlys).
- pNewFormat->MakeFrms();
+ pNewFormat->MakeFrames();
OSL_ENSURE( pNew, "No Label inserted" );
@@ -1400,10 +1400,10 @@ void SwDoc::SetAllUniqueFlyNames()
{
sal_Int32 n, nFlyNum = 0, nGrfNum = 0, nOLENum = 0;
- ResId nFrmId( STR_FRAME_DEFNAME, *pSwResMgr ),
+ ResId nFrameId( STR_FRAME_DEFNAME, *pSwResMgr ),
nGrfId( STR_GRAPHIC_DEFNAME, *pSwResMgr ),
nOLEId( STR_OBJECT_DEFNAME, *pSwResMgr );
- const OUString sFlyNm( nFrmId );
+ const OUString sFlyNm( nFrameId );
const OUString sGrfNm( nGrfId );
const OUString sOLENm( nOLEId );
@@ -1584,7 +1584,7 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
const SwFrameFormat* pFlyFormat = pNd->GetFlyFormat();
while( pFlyFormat )
{
- pItem = &pFlyFormat->GetFrmDir();
+ pItem = &pFlyFormat->GetFrameDir();
if( FRMDIR_ENVIRONMENT == pItem->GetValue() )
{
pItem = nullptr;
@@ -1606,7 +1606,7 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
{
const SwPageDesc* pPgDsc = pNd->FindPageDesc( false );
if( pPgDsc )
- pItem = &pPgDsc->GetMaster().GetFrmDir();
+ pItem = &pPgDsc->GetMaster().GetFrameDir();
}
}
if( !pItem )
@@ -1623,9 +1623,9 @@ bool SwDoc::IsInVerticalText( const SwPosition& rPos, const Point* pPt ) const
return FRMDIR_VERT_TOP_RIGHT == nDir || FRMDIR_VERT_TOP_LEFT == nDir;
}
-std::set<SwRootFrm*> SwDoc::GetAllLayouts()
+std::set<SwRootFrame*> SwDoc::GetAllLayouts()
{
- std::set<SwRootFrm*> aAllLayouts;
+ std::set<SwRootFrame*> aAllLayouts;
SwViewShell *pStart = getIDocumentLayoutAccess().GetCurrentViewShell();
if(pStart)
{
@@ -717,8 +717,8 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
OSL_ENSURE( pOldFormat, "Couldn't find the Fly's Format." );
// #i115719#
- // <title> and <description> attributes are lost when calling <DelFrms()>.
- // Thus, keep them and restore them after the calling <MakeFrms()>
+ // <title> and <description> attributes are lost when calling <DelFrames()>.
+ // Thus, keep them and restore them after the calling <MakeFrames()>
const bool bIsSwFlyFrameFormatInstance( dynamic_cast<SwFlyFrameFormat*>(pOldFormat) != nullptr );
const OUString sTitle( bIsSwFlyFrameFormatInstance